``perspective.table`` contains ``Table`` and ``View``, the data primitives of Perspective. 

For usage, see the `Python User Guide </docs/md/python.html>`_.

Table
=====
.. autoclass:: perspective.table.Table
   :members:
   :undoc-members:
   :show-inheritance:

View
====
.. autoclass:: perspective.table.view.View
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: to_arrow
